==> blesta-5.10.2.zip: blesta/language/nl_nl/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Batch-proces';
$lang['AdminBilling.batch.field_passphrase'] = 'Passphrase';
$lang['AdminBilling.batch.text_description'] = 'Voer je wachtwoordzin in om alle facturen die zijn gepland voor automatische afschrijving handmatig batchgewijs te verwerken met een lokaal opgeslagen betaalrekening.';
$lang['AdminBilling.batch.no_passphrase'] = 'Handmatige batchverwerking is niet ingeschakeld.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Batch';
$lang['AdminBilling.batch.page_title'] = 'Facturering Batch';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Markering afgedrukt';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Afdrukken';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Datum verzonden';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Datum';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Datum gefactureerd';
$lang['AdminBilling.printqueue.heading_due'] = 'Due';
$lang['AdminBilling.printqueue.heading_paid'] = 'Betaald';
$lang['AdminBilling.printqueue.heading_amount'] = 'Bedrag';
$lang['AdminBilling.printqueue.heading_client'] = 'Klant #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Factuur #';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Er staan geen facturen in de wachtrij om te worden afgedrukt.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Er zijn geen eerder afgedrukte facturen.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Afdrukwachtrij';
$lang['AdminBilling.printqueue.category_printed'] = 'Eerder gedrukt';
$lang['AdminBilling.printqueue.category_to_print'] = 'Afdrukken';
$lang['AdminBilling.printqueue.page_title'] = 'Afdrukwachtrij facturering';
$lang['AdminBilling.invoices.text_edit'] = 'Bewerk';
$lang['AdminBilling.invoices.applied_no_results'] = 'Op deze factuur zijn geen transacties toegepast.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Opties';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Toegepast op';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Toegepast';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Bedrag';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Type betaling';
$lang['AdminBilling.transactions.applied_no_results'] = 'Deze transactie is op geen enkele factuur toegepast.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Toegepast op';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Bedrag';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Factuur';
$lang['AdminBilling.transactions.no_results'] = 'Er zijn geen transacties met deze status.';
$lang['AdminBilling.transactions.option_edit'] = 'Bewerk';
$lang['AdminBilling.transactions.category_returned'] = 'Geretourneerd';
$lang['AdminBilling.transactions.category_refunded'] = 'Terugbetaald';
$lang['AdminBilling.transactions.category_pending'] = 'In afwachting van';
$lang['AdminBilling.transactions.category_error'] = 'Fout';
$lang['AdminBilling.transactions.category_voided'] = 'Ongeldig';
$lang['AdminBilling.transactions.category_declined'] = 'Afgewezen';
$lang['AdminBilling.transactions.category_approved'] = 'Goedgekeurd';
$lang['AdminBilling.transactions.heading_options'] = 'Opties';
$lang['AdminBilling.transactions.heading_date'] = 'Datum';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Referentie #';
$lang['AdminBilling.transactions.heading_number'] = 'Aantal';
$lang['AdminBilling.transactions.heading_applied'] = 'Toegepast';
$lang['AdminBilling.transactions.heading_credit'] = 'Gecrediteerd';
$lang['AdminBilling.transactions.heading_amount'] = 'Bedrag';
$lang['AdminBilling.transactions.heading_type'] = 'Type';
$lang['AdminBilling.transactions.heading_client'] = 'Klant #';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transacties';
$lang['AdminBilling.transactions.page_title'] = 'Factureringstransacties';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Reden voor annulering: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Deze service heeft geen details.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Stuur  in';
$lang['AdminBilling.services.action.field_client'] = 'Klant:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push naar klant';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Niet annuleren';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Specifieke datum';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Einde Termijn';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Annulering';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Er zijn geen diensten met deze status.';
$lang['AdminBilling.services.text_never'] = 'Nooit';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Gepland';
$lang['AdminBilling.services.category_in_review'] = 'Terugblik';
$lang['AdminBilling.services.category_pending'] = 'In afwachting van';
$lang['AdminBilling.services.category_suspended'] = 'Geschorst';
$lang['AdminBilling.services.category_canceled'] = 'Geannuleerd';
$lang['AdminBilling.services.category_active'] = 'Actief';
$lang['AdminBilling.services.confirm_delete'] = 'Weet je zeker dat je deze service wilt verwijderen?';
$lang['AdminBilling.services.option_delete'] = 'Verwijder';
$lang['AdminBilling.services.option_manage'] = 'Beheer';
$lang['AdminBilling.services.heading_options'] = 'Opties';
$lang['AdminBilling.services.heading_datecanceled'] = 'Datum Geannuleerd';
$lang['AdminBilling.services.heading_datesuspended'] = 'Datum Geschorst';
$lang['AdminBilling.services.heading_daterenews'] = 'Datum Verlenging';
$lang['AdminBilling.services.heading_dateadded'] = 'Datum toegevoegd';
$lang['AdminBilling.services.heading_term'] = 'Term';
$lang['AdminBilling.services.heading_label'] = 'Label';
$lang['AdminBilling.services.heading_package'] = 'Pakket';
$lang['AdminBilling.services.heading_client'] = 'Klant #';
$lang['AdminBilling.services.boxtitle_services'] = 'Diensten';
$lang['AdminBilling.services.page_title'] = 'Factureringsdiensten';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Er zijn geen facturen gekoppeld aan deze offerte.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Bekijk';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Opties';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Datum gefactureerd';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Betaald';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Bedrag';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Factuur #';
$lang['AdminBilling.quotations.no_results'] = 'Er zijn geen offertes met deze status.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Weet je zeker dat je dit citaat wilt goedkeuren?';
$lang['AdminBilling.quotations.option_approve'] = 'Goedkeuren';
$lang['AdminBilling.quotations.option_invoice'] = 'Factuur maken';
$lang['AdminBilling.quotations.option_view'] = 'Bekijk';
$lang['AdminBilling.quotations.option_edit'] = 'Bewerk';
$lang['AdminBilling.quotations.heading_options'] = 'Opties';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Vervaldatum';
$lang['AdminBilling.quotations.heading_date_created'] = 'Aanmaakdatum';
$lang['AdminBilling.quotations.heading_total'] = 'Bedrag';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Subtotaal';
$lang['AdminBilling.quotations.heading_staff'] = 'Geciteerd door';
$lang['AdminBilling.quotations.heading_title'] = 'Titel';
$lang['AdminBilling.quotations.heading_client'] = 'Klant #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citaat #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citaten';
$lang['AdminBilling.quotations.page_title'] = 'Factuur citaten';
$lang['AdminBilling.invoices.no_results'] = 'Er zijn geen facturen met deze status.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s keer';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s jaren';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s maanden';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s weken';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dagen';
$lang['AdminBilling.invoices.term_year'] = '%1$s jaar';
$lang['AdminBilling.invoices.term_month'] = '%1$s maand';
$lang['AdminBilling.invoices.term_week'] = '%1$s week';
$lang['AdminBilling.invoices.term_day'] = '%1$s dag';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +belasting';
$lang['AdminBilling.invoices.option_pay'] = 'Betaal';
$lang['AdminBilling.invoices.option_view'] = 'Bekijk';
$lang['AdminBilling.invoices.option_edit'] = 'Bewerk';
$lang['AdminBilling.invoices.category_recurring'] = 'Terugkerend';
$lang['AdminBilling.invoices.category_pending'] = 'In afwachting van';
$lang['AdminBilling.invoices.category_pastdue'] = 'Vervallen';
$lang['AdminBilling.invoices.category_voided'] = 'Ongeldig';
$lang['AdminBilling.invoices.category_closed'] = 'Gesloten';
$lang['AdminBilling.invoices.category_drafts'] = 'Concepten';
$lang['AdminBilling.invoices.category_open'] = 'Open';
$lang['AdminBilling.invoices.heading_count'] = 'Graaf';
$lang['AdminBilling.invoices.heading_duration'] = 'Duur';
$lang['AdminBilling.invoices.heading_term'] = 'Term';
$lang['AdminBilling.invoices.heading_options'] = 'Opties';
$lang['AdminBilling.invoices.heading_datedue'] = 'Datum';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Datum gefactureerd';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Datum Gesloten';
$lang['AdminBilling.invoices.heading_due'] = 'Due';
$lang['AdminBilling.invoices.heading_paid'] = 'Betaald';
$lang['AdminBilling.invoices.heading_amount'] = 'Bedrag';
$lang['AdminBilling.invoices.heading_client'] = 'Klant #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Terugkerend #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Factuur #';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Facturen';
$lang['AdminBilling.invoices.page_title'] = 'Facturen';
$lang['AdminBilling.managewidgets.text_author'] = 'Auteur:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Sleep widgets van rechts naar links om ze toe te voegen aan je factuuroverzicht, of van links naar rechts om ze te verwijderen.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Selecteer hieronder een lay-out om uw factureringsoverzicht aan te passen.';
$lang['AdminBilling.index.action_batch'] = 'Items in afwachting van batch';
$lang['AdminBilling.index.action_printqueue'] = 'Items in afwachting van afdrukken';
$lang['AdminBilling.index.no_actions'] = 'Er zijn geen actiepunten.';
$lang['AdminBilling.index.heading_actions'] = 'Actiepunten';
$lang['AdminBilling.index.customize_dashboard'] = 'Overzicht aanpassen';
$lang['AdminBilling.index.manage_widgets'] = 'Widgets beheren';
$lang['AdminBilling.index.page_title'] = 'Overzicht facturering';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'De geplande annuleringsdatum mag niet in het verleden liggen.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'De ingevoerde wachtwoordzin is ongeldig.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Er zijn geen facturen geselecteerd.';
$lang['AdminBilling.!success.services_pushed'] = 'De geselecteerde services zijn met succes naar de nieuwe klant gepushed.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'De geselecteerde diensten zijn niet langer geannuleerd.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'De geselecteerde diensten werden met succes ingepland om geannuleerd te worden.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'De geselecteerde facturen zijn gemarkeerd als afgedrukt.';

==> blesta-5.11.4.zip: blesta/language/nl_nl/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Batch-proces';
$lang['AdminBilling.batch.field_passphrase'] = 'Passphrase';
$lang['AdminBilling.batch.text_description'] = 'Voer je wachtwoordzin in om alle facturen die zijn gepland voor automatische afschrijving handmatig batchgewijs te verwerken met een lokaal opgeslagen betaalrekening.';
$lang['AdminBilling.batch.no_passphrase'] = 'Handmatige batchverwerking is niet ingeschakeld.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Batch';
$lang['AdminBilling.batch.page_title'] = 'Facturering Batch';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Markering afgedrukt';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Afdrukken';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Datum verzonden';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Datum';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Datum gefactureerd';
$lang['AdminBilling.printqueue.heading_due'] = 'Due';
$lang['AdminBilling.printqueue.heading_paid'] = 'Betaald';
$lang['AdminBilling.printqueue.heading_amount'] = 'Bedrag';
$lang['AdminBilling.printqueue.heading_client'] = 'Klant #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Factuur #';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Er staan geen facturen in de wachtrij om te worden afgedrukt.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Er zijn geen eerder afgedrukte facturen.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Afdrukwachtrij';
$lang['AdminBilling.printqueue.category_printed'] = 'Eerder gedrukt';
$lang['AdminBilling.printqueue.category_to_print'] = 'Afdrukken';
$lang['AdminBilling.printqueue.page_title'] = 'Afdrukwachtrij facturering';
$lang['AdminBilling.invoices.text_edit'] = 'Bewerk';
$lang['AdminBilling.invoices.applied_no_results'] = 'Op deze factuur zijn geen transacties toegepast.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Opties';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Toegepast op';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Toegepast';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Bedrag';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Type betaling';
$lang['AdminBilling.transactions.applied_no_results'] = 'Deze transactie is op geen enkele factuur toegepast.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Toegepast op';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Bedrag';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Factuur';
$lang['AdminBilling.transactions.no_results'] = 'Er zijn geen transacties met deze status.';
$lang['AdminBilling.transactions.option_edit'] = 'Bewerk';
$lang['AdminBilling.transactions.category_returned'] = 'Geretourneerd';
$lang['AdminBilling.transactions.category_refunded'] = 'Terugbetaald';
$lang['AdminBilling.transactions.category_pending'] = 'In afwachting van';
$lang['AdminBilling.transactions.category_error'] = 'Fout';
$lang['AdminBilling.transactions.category_voided'] = 'Ongeldig';
$lang['AdminBilling.transactions.category_declined'] = 'Afgewezen';
$lang['AdminBilling.transactions.category_approved'] = 'Goedgekeurd';
$lang['AdminBilling.transactions.heading_options'] = 'Opties';
$lang['AdminBilling.transactions.heading_date'] = 'Datum';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Referentie #';
$lang['AdminBilling.transactions.heading_number'] = 'Aantal';
$lang['AdminBilling.transactions.heading_applied'] = 'Toegepast';
$lang['AdminBilling.transactions.heading_credit'] = 'Gecrediteerd';
$lang['AdminBilling.transactions.heading_amount'] = 'Bedrag';
$lang['AdminBilling.transactions.heading_type'] = 'Type';
$lang['AdminBilling.transactions.heading_client'] = 'Klant #';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transacties';
$lang['AdminBilling.transactions.page_title'] = 'Factureringstransacties';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Reden voor annulering: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Deze service heeft geen details.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Stuur  in';
$lang['AdminBilling.services.action.field_client'] = 'Klant:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push naar klant';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Niet annuleren';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Specifieke datum';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Einde Termijn';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Annulering';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Er zijn geen diensten met deze status.';
$lang['AdminBilling.services.text_never'] = 'Nooit';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Gepland';
$lang['AdminBilling.services.category_in_review'] = 'Terugblik';
$lang['AdminBilling.services.category_pending'] = 'In afwachting van';
$lang['AdminBilling.services.category_suspended'] = 'Geschorst';
$lang['AdminBilling.services.category_canceled'] = 'Geannuleerd';
$lang['AdminBilling.services.category_active'] = 'Actief';
$lang['AdminBilling.services.confirm_delete'] = 'Weet je zeker dat je deze service wilt verwijderen?';
$lang['AdminBilling.services.option_delete'] = 'Verwijder';
$lang['AdminBilling.services.option_manage'] = 'Beheer';
$lang['AdminBilling.services.heading_options'] = 'Opties';
$lang['AdminBilling.services.heading_datecanceled'] = 'Datum Geannuleerd';
$lang['AdminBilling.services.heading_datesuspended'] = 'Datum Geschorst';
$lang['AdminBilling.services.heading_daterenews'] = 'Datum Verlenging';
$lang['AdminBilling.services.heading_dateadded'] = 'Datum toegevoegd';
$lang['AdminBilling.services.heading_term'] = 'Term';
$lang['AdminBilling.services.heading_label'] = 'Label';
$lang['AdminBilling.services.heading_package'] = 'Pakket';
$lang['AdminBilling.services.heading_client'] = 'Klant #';
$lang['AdminBilling.services.boxtitle_services'] = 'Diensten';
$lang['AdminBilling.services.page_title'] = 'Factureringsdiensten';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Er zijn geen facturen gekoppeld aan deze offerte.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Bekijk';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Opties';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Datum gefactureerd';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Betaald';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Bedrag';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Factuur #';
$lang['AdminBilling.quotations.no_results'] = 'Er zijn geen offertes met deze status.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Weet je zeker dat je dit citaat wilt goedkeuren?';
$lang['AdminBilling.quotations.option_approve'] = 'Goedkeuren';
$lang['AdminBilling.quotations.option_invoice'] = 'Factuur maken';
$lang['AdminBilling.quotations.option_view'] = 'Bekijk';
$lang['AdminBilling.quotations.option_edit'] = 'Bewerk';
$lang['AdminBilling.quotations.heading_options'] = 'Opties';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Vervaldatum';
$lang['AdminBilling.quotations.heading_date_created'] = 'Aanmaakdatum';
$lang['AdminBilling.quotations.heading_total'] = 'Bedrag';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Subtotaal';
$lang['AdminBilling.quotations.heading_staff'] = 'Geciteerd door';
$lang['AdminBilling.quotations.heading_title'] = 'Titel';
$lang['AdminBilling.quotations.heading_client'] = 'Klant #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citaat #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citaten';
$lang['AdminBilling.quotations.page_title'] = 'Factuur citaten';
$lang['AdminBilling.invoices.no_results'] = 'Er zijn geen facturen met deze status.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s keer';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s jaren';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s maanden';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s weken';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dagen';
$lang['AdminBilling.invoices.term_year'] = '%1$s jaar';
$lang['AdminBilling.invoices.term_month'] = '%1$s maand';
$lang['AdminBilling.invoices.term_week'] = '%1$s week';
$lang['AdminBilling.invoices.term_day'] = '%1$s dag';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +belasting';
$lang['AdminBilling.invoices.option_pay'] = 'Betaal';
$lang['AdminBilling.invoices.option_view'] = 'Bekijk';
$lang['AdminBilling.invoices.option_edit'] = 'Bewerk';
$lang['AdminBilling.invoices.category_recurring'] = 'Terugkerend';
$lang['AdminBilling.invoices.category_pending'] = 'In afwachting van';
$lang['AdminBilling.invoices.category_pastdue'] = 'Vervallen';
$lang['AdminBilling.invoices.category_voided'] = 'Ongeldig';
$lang['AdminBilling.invoices.category_closed'] = 'Gesloten';
$lang['AdminBilling.invoices.category_drafts'] = 'Concepten';
$lang['AdminBilling.invoices.category_open'] = 'Open';
$lang['AdminBilling.invoices.heading_count'] = 'Graaf';
$lang['AdminBilling.invoices.heading_duration'] = 'Duur';
$lang['AdminBilling.invoices.heading_term'] = 'Term';
$lang['AdminBilling.invoices.heading_options'] = 'Opties';
$lang['AdminBilling.invoices.heading_datedue'] = 'Datum';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Datum gefactureerd';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Datum Gesloten';
$lang['AdminBilling.invoices.heading_due'] = 'Due';
$lang['AdminBilling.invoices.heading_paid'] = 'Betaald';
$lang['AdminBilling.invoices.heading_amount'] = 'Bedrag';
$lang['AdminBilling.invoices.heading_client'] = 'Klant #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Terugkerend #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Factuur #';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Facturen';
$lang['AdminBilling.invoices.page_title'] = 'Facturen';
$lang['AdminBilling.managewidgets.text_author'] = 'Auteur:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Sleep widgets van rechts naar links om ze toe te voegen aan je factuuroverzicht, of van links naar rechts om ze te verwijderen.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Selecteer hieronder een lay-out om uw factureringsoverzicht aan te passen.';
$lang['AdminBilling.index.action_batch'] = 'Items in afwachting van batch';
$lang['AdminBilling.index.action_printqueue'] = 'Items in afwachting van afdrukken';
$lang['AdminBilling.index.no_actions'] = 'Er zijn geen actiepunten.';
$lang['AdminBilling.index.heading_actions'] = 'Actiepunten';
$lang['AdminBilling.index.customize_dashboard'] = 'Overzicht aanpassen';
$lang['AdminBilling.index.manage_widgets'] = 'Widgets beheren';
$lang['AdminBilling.index.page_title'] = 'Overzicht facturering';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'De geplande annuleringsdatum mag niet in het verleden liggen.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'De ingevoerde wachtwoordzin is ongeldig.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Er zijn geen facturen geselecteerd.';
$lang['AdminBilling.!success.services_pushed'] = 'De geselecteerde services zijn met succes naar de nieuwe klant gepushed.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'De geselecteerde diensten zijn niet langer geannuleerd.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'De geselecteerde diensten werden met succes ingepland om geannuleerd te worden.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'De geselecteerde facturen zijn gemarkeerd als afgedrukt.';
$lang['AdminBilling.services.action.field_suspension_reason'] = 'Reden voor schorsing:';
$lang['AdminBilling.services.action.unsuspend'] = 'Ontspannen';
$lang['AdminBilling.services.action.suspend'] = 'opschorten';
$lang['AdminBilling.!success.services_unsuspended'] = 'De geselecteerde services werden met succes uitgeschakeld.';
$lang['AdminBilling.!success.services_suspended'] = 'De geselecteerde services zijn met succes opgeschort.';
